<!-- markdownlint-disable MD041 -->

<p align="center">
  <a href="https://bloomberg.github.io/blazingmq">
    <picture>
      <source media="(prefers-color-scheme: dark)" srcset="assets/images/blazingmq_logo_label_dark.svg">
      <img src="assets/images/blazingmq_logo_label.svg" width="70%">
    </picture>
  </a>
</p>

---

[![BlazingMQ](https://img.shields.io/badge/BlazingMQ-blue)](https://github.com/bloomberg/blazingmq)
[![OS Linux](https://img.shields.io/badge/OS-Linux-blue)](#)
[![OS MacOS](https://img.shields.io/badge/OS-MacOS-blue)](#)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue)](LICENSE)
[![Python](https://img.shields.io/badge/Python-blue)](#)
[![MessageQueue](https://img.shields.io/badge/MessageQueue-blue)](#)
[![Documentation](https://img.shields.io/badge/Documentation-blue)](https://bloomberg.github.io/blazingmq)
[![Code Style](https://img.shields.io/badge/Black-black)](#)
![Supported Python versions](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20%7C%203.1220%7C%203.13-blue?logo=python)

# BlazingMQ Python SDK

This repository provides the official Python client library, as well as examples
of how applications can interact with BlazingMQ. BlazingMQ is an open source
message queue system, which focuses on efficiency, reliability, and a rich feature
set. Please see the BlazingMQ [repo](https://github.com/bloomberg/blazingmq)
and [documentation](https://bloomberg.github.io/blazingmq) for more details
about BlazingMQ.

This Python client is fully supported by the BlazingMQ team, and we intend to
provide feature and/or API parity with the BlazingMQ C++ client library.

## Menu

- [Building](#building)
- [Contributions](#contributions)
- [License](#license)
- [Code of Conduct](#code-of-conduct)
- [Security Vulnerability Reporting](#security-vulnerability-reporting)


## Building

For instructions on how to build and test the package, check
[docs/BUILD.md](docs/BUILD.md).


## Contributions

We welcome your contributions to help us improve and extend this project!

We welcome issue reports [here](../../issues); be sure to choose the proper
issue template for your issue, so that we can be sure you're providing us with
the necessary information.

Before sending a [Pull Request](../../pulls), please make sure you have read
our [Contribution
Guidelines](https://github.com/bloomberg/.github/blob/main/CONTRIBUTING.md).


## License

The BlazingMQ Python SDK is Apache 2.0 licensed, as found in the
[LICENSE](LICENSE) file.


## Code of Conduct

This project has adopted a [Code of
Conduct](https://github.com/bloomberg/.github/blob/main/CODE_OF_CONDUCT.md).
If you have any concerns about the Code, or behavior which you have experienced
in the project, please contact us at opensource@bloomberg.net.


## Security Vulnerability Reporting

If you believe you have identified a security vulnerability in this project,
please send an email to the project team at opensource@bloomberg.net, detailing
the suspected issue and any methods you've found to reproduce it.

Please do NOT open an issue in the GitHub repository, as we'd prefer to keep
vulnerability reports private until we've had an opportunity to review and
address them.
